@@ -227,13 +227,13 @@ function detailAppointmentOnload(callback)
 							var sShownAs = "";
 							switch (fieldsToGet.data[a_d_data]) {
 								case 1	:	newClassName = "appointmentRESERVED";
-											sShownAs = _("reserved");
-											aPrintDetailApp[7] = Print.createContent(_("Display as:"),_("reserved"));
+											sShownAs = _("booked");
+											aPrintDetailApp[7] = Print.createContent(_("Display as:"),_("booked"));
 											break;
 											
 								case 2	:	newClassName = "appointmentTEMPORARY";
-											sShownAs = _("temporary");
-											aPrintDetailApp[7] = Print.createContent(_("Display as:"),_("temporary"));
+											sShownAs = _("tentative");
+											aPrintDetailApp[7] = Print.createContent(_("Display as:"),_("tentative"));
 											break;
 											
 								case 3	:	newClassName = "appointmentABSENT";
@@ -242,8 +242,11 @@ function detailAppointmentOnload(callback)
 											break;
 											
 								case 4	:	newClassName = "appointmentFREE";
+								            //#. appointment availability
 											sShownAs = _("free");
-											aPrintDetailApp[7] = Print.createContent(_("Display as:"),_("free"));
+											aPrintDetailApp[7] = Print.createContent(_("Display as:"),
+	                                            //#. appointment availability
+										        _("free"));
 											break;			
 									
 								default	:	newClassName = "appointmentNONE";
