@@ -296,6 +296,9 @@ function monthView() {
 	this.redraw = function (){};
 	this.show_we = 1;
 	this.show_ww = 2;
+	
+	var Self = this;
+	
 	// month headline
 	this.headline = new I18nNode(function() {
         return formatDateTime("MMMM yyyy", new Date(Date.UTC(activeYear,activeMonth,activeDay,0,0,0)));
@@ -303,6 +306,13 @@ function monthView() {
 	if (!$("monthviewheader").firstChild) {
 	    $("monthviewheader").appendChild(this.headline.node);
 	}
+	
+	this.updateView = function() {
+        Self.clearMonthView();
+        Self.iterateStorage();
+        lastUpdateOfCalendarTimestamp = storageCache.current.timestamp;
+        calendar_HeaderUpdate(Self.storage.ids.length);
+    };
 }
 
 function moveAppToNewStart(objc, startTimeParam, endTimeParam, fn_opt) {
@@ -535,10 +545,22 @@ monthView.prototype = {
 		//	aAppointments = this.getAppointments(currentDay.nDate,oCalendarTool.nMonth,
 		//															currentDay.nCurrMonth,aAllAppointments);
 	
+	    // build a unique string out of folder, id and recurrence position 
+	    function buildIDString(obj) {
+            return String(obj.folder + "." + obj.id + "." + (obj.recurrence_position || 0))
+        }
+        
+	    // filter duplicates, ignore apps which have been already drawn
+        for (var a in this.aAppointmentAssoc) {
+            var obj = this.aAppointmentAssoc[a];
+            if (buildIDString(obj) === buildIDString(calendarObjects)) {
+                return;
+            }
+        }
+	    
 		var id = calendarObjects.id;
 		var folder_id = calendarObjects.folder;
 		var selectedAppointmentWeek={id : id, folder : folder_id};
-		var divAppId = 'appInWeekView' + folder_id + "_" + id;
 
 		var title = calendarObjects.title;
 		var start_date = calendarObjects.start_date;
@@ -843,9 +865,7 @@ monthView.prototype = {
 	getStorage: function(fnParamComplete) {
 	    var Self = this;
         if (this.storage) {
-            this.storage.events.unregister("Changed", function() {
-                Self.updateView();
-            });
+            this.storage.events.unregister("Changed", this.updateView);
         }
         this.clearMonthView();
         var oChDate = this.getDateFromDay(this.oCalendar.aWeeks[0].aDays[0]);
@@ -878,20 +898,11 @@ monthView.prototype = {
                  calendar_makeID);
     },
     
-    updateView: function() {
-        this.clearMonthView();
-        this.iterateStorage();
-        lastUpdateOfCalendarTimestamp = storageCache.current.timestamp;
-        calendar_HeaderUpdate(this.storage.ids.length);
-    },
-    
     iterateStorage: function(storage) {
         var Self = this;
         if (storage) {
             Self.storage = storage;
-            Self.storage.events.register("Changed", function() {
-                Self.updateView();
-            });
+            Self.storage.events.register("Changed", Self.updateView);
         }
         Self.storage.newIterate(Self.storage.ids, emptyFunction, function(x,y) {
             Self.buildAppointments(x,y);
