@@ -665,6 +665,16 @@ register("OX_Configuration_Loaded", function () {
 	    buttons.addWidget(save_button);
 	
 	    var cancel_button = new ox.UI.Button(_("Cancel"));
+	    split.cancelView = function() {
+	        this.isNew = false;
+            if (this.afterSave) {
+                this.afterSave();
+            } else {
+                var data = clone(this.original);
+                data.id = this.id;
+                this.set(data);
+            }
+	    };
 	    cancel_button.click = function() { split.cancelView(); };
 	    buttons.addWidget(cancel_button);
 	    
