@@ -193,6 +193,7 @@ registerView("contacts/cards",
 		triggerEvent('OX_Delete_Search');
 		if(configGetKey("gui.contacts.cardsToViewPerColumn") == "auto") {
 			resizeEvents.unregister("Resized",showContactCards);
+			removeDOMEvent(scrollerCbar, "scroll", scrollCardView);
 		}
 		myLetterContactTab.unregisterTab();
 	},
@@ -1092,15 +1093,6 @@ function showContactCards()
 
 	addDOMEvent(scrollerCbar, "scroll", scrollCardView);
 
-//	var tableContactCardsArea = $("contactCardTable");
-//
-//	if (tableContactCardsArea.addEventListener) {
-//		tableContactCardsArea.addEventListener("DOMMouseScroll", wheel_callback, false);
-//	} else {
-//		addDOMEvent(tableContactCardsArea, "mousewheel", wheel_callback);
-//	}
-//	tableContactCardsArea.onselectstart = function() { return false; };
-
 	// works under mac ox lion as well:
 	jQuery('#contactCardTable').bind('mousewheel DOMMouseScroll', fnWheel)
 	    .get(0).onselectstart = function () { return false; };
@@ -1414,8 +1406,9 @@ function writeCards(currentCardId, columnForDisplyCards, oCurrentContent)
     		}
         }
 
-		if(data.distribution_list) {
-			for(var t = 0; t < 4 && t < data.distribution_list.length; t++) {
+		if (data.distribution_list) {
+			for (var t = 0; t < 4 && t < data.distribution_list.length; t++) {
+			    if (!data.distribution_list[t].mail) continue;
 				var contactObj = cloneContactNodeById("contact_0_0x",
                     (t == 3 && data.distribution_list.length != 4) ? "\xa0\xa0..."
                         : data.distribution_list[t].mail,
@@ -1514,27 +1507,16 @@ function showDetailCard(cardDiv_n)
 function fnWheel(e) {
     if (!e.isDefaultPrevented()) {
         e.preventDefault();
+        var a = e;
+        if (!e.detail || !e.wheelDelta) {
+        	a = e.originalEvent;
+        }
         // update scrollbar
-        scrollerCbar.scrollLeft += contacCardWidth * (e.wheelDelta >= 0 || e.detail < 0 ? -1 : +1);
+        scrollerCbar.scrollLeft += contacCardWidth * (a.wheelDelta >= 0 || a.detail < 0 ? -1 : +1);
+        a = null;
     }
 }
 
-//function wheel_callback(e)
-//{
-//	wheelTableCard(e);
-//}
-//
-//function wheelTableCard(e)
-//{
-//	if (e.wheelDelta >= 0 || e.detail < 0)
-//	{
-//		scrollerCbar.scrollLeft -= contacCardWidth;
-//	} else
-//	{
-//		scrollerCbar.scrollLeft += contacCardWidth;
-//	}
-//}
-
 /********************************** Edit Cards *****************************************************************/
 
 function setStatusDLSelection() {
