@@ -154,8 +154,7 @@ function folderPath() {
 	ox.api.folder.get({
 	    folder: clickedItemForSave,
 	    success: function (data) {
-    	    var nPermission = ox.api.folder.derive("permissions", data, 0).bit;
-    		if (nPermission < 2) {
+    		if (ox.api.folder.derive("permissions", data, 14).bit < 2) {
     			triggerEvent("OX_New_Error", 4, _("You do not have write permission for this folder. The new contact will be saved in your personal contacts folder. "));
     			clickedItemForSave = configGetKey("folder.contacts");
     		}
@@ -170,7 +169,8 @@ function folderPath() {
     		folderViewSettingsNewContact["calendar"] = 4;
     		folderViewSettingsNewContact["tasks"] = 4;
     		folderViewSettingsNewContact["infostore"] = 4;
-    		if(!dlTreeLoaded){
+    		if (!dlTreeLoaded){
+    		    addOnClose($("treeDialogNewDL"), toggleTreePath);
     			ox.api.ui.selectFolder({
     		    	type: "contacts",
     		    	id: "select-folder-popup-distribution-list",
@@ -179,9 +179,7 @@ function folderPath() {
     		    	minPerms: 2, // create objects
     		    	destroy: false
     		    });
-    
     			dlTreeLoaded = true;
-    			
     			ox.api.folder.getPathString({
         		    folder: clickedItemForSave,
         		    success: cb_DLgetpath
@@ -224,21 +222,19 @@ function toggleTreePath(){
     // prevent a second popup in background during folder selection
     if ($("treeDialogNewParticitpantList").style.display === "none" ) {
     	if(!dlTreeVisible){
-    		centerPopupWindow($("treeDialogNewDL"));
+    		centerPopupWindow($("treeDialogNewDL"), 400, 300);
     		$("treeDialogNewDL").style.display = "block";
-    		$("treeDialogNewDL").style.top = "130px";
-    		$("treeDialogNewDL").style.left = "170px";
     		dlTreeVisible = true;
-    		if(!dlTreeLoaded){
+    		if (!dlTreeLoaded){
     			newDlFolderTree.load(corewindow.optFolderState.getState('folder_tree_info'));
     			dlTreeLoaded = true;
-    			}
-    	}
-    	else{
+			}
+    	} else{
     		$("treeDialogNewDL").style.display = "none";
     		dlTreeVisible = false;
     	}
     }
+    ox.api.setModal(dlTreeVisible);
 }
 
 var callback_new = callback_update = function (arg) {
@@ -677,13 +673,14 @@ function fillFields(data) {
 
 	if (data['distribution_list']) {
 		// shortcut
-		var dl = data['distribution_list'];				
+		var dl = data['distribution_list'], fl = {};
 		// loop entries
-		for(i = 0; i < dl.length; i++ ) {
+		for (var i = 0; i < dl.length; i++ ) {
 		    // add to storage (live grid)
             var cObj = { 'display_name': dl[i].display_name || "",
                     'email': dl[i].mail || ""
             };
+            
 			var id = dl[i].id;
 			// external address without id
 			if ((id === undefined || id === null) || trimStr(id).length === 0 
@@ -691,6 +688,10 @@ function fillFields(data) {
 			    id = new Date().getTime() + "." + parseInt(Math.random() * 10000);
 			    cObj.external = true;
 			    cObj.mail_field = 0;
+			    if (fl[cObj.email]) {
+			        continue;
+			    }
+			    fl[cObj.email] = true;
 			}
 			cObj.id = id;
 			// if not set, use default 1 - required to set recurrence
@@ -698,8 +699,13 @@ function fillFields(data) {
 				dl[i].mail_field = 1;
 			}
 			cObj.recurrence = dl[i].mail_field - 1;
-			distruBigGrid.storage.append([cObj]);
-		}				
+			
+			if (!fl[id]) {
+			    distruBigGrid.storage.append([cObj]);
+			    fl[id] = true;
+			}
+		}
+		fl = dl = null;
 	}
 }
 
@@ -758,7 +764,10 @@ function finalFunction() {
 }
 
 function setBeforeUnload(on) {
-    messageOnCancel = on;
+    if (on !== undefined && on !== messageOnCancel) {
+        messageOnCancel = on;
+    }
+    ctrl.dirty(messageOnCancel);
 }
 
 // init window controller
@@ -771,3 +780,4 @@ ctrl.set("beforeunload", function () {
 });
 
 ctrl.set("confirm", closeWindow);
+ctrl.set("dirty", setBeforeUnload);
