@@ -616,7 +616,7 @@ function minicalenable(e,dragType,draggedObjects,mouseposition,targetNode,node)
                 }
                 setDefaultNodeType(iconNode, found);
             });
-        } else if (dragType === "mail") {
+        } else if (dragType === "mail" || dragType === "calendar") {
             setDefaultNodeType(iconNode, true);
         }
     }
