@@ -79,8 +79,11 @@ function openInfoStoreCategoriesDialog() {
 	});
 }
 
-function setBeforeUnload(on){
-    messageOnCancel = on;
+function setBeforeUnload(on) {
+    if (on !== undefined && on !== messageOnCancel) {
+        messageOnCancel = on;
+    }
+    ctrl.dirty(messageOnCancel);
 }
 
 function detachFile()
@@ -335,45 +338,26 @@ function activateUpload()
 	}
 }
 
-function showTreeDialog()
-{	
-	centerPopupWindow($("TreeDialogNewInfoStore"));
-	document.getElementById("TreeDialogNewInfoStore").style.display = "block";
-	document.getElementById("TreeDialogNewInfoStore").style.top = "30px";
-	document.getElementById("TreeDialogNewInfoStore").style.left = "170px";
 
-	if(!bCreated)
-		loadFolderTreeInfo();
-}
-
-function hideTree(){
-	document.getElementById("TreeDialogNewInfoStore").style.display = "none";	
-}
-
-function toggleTreeDialog()
-{	
-	if(!treeVisible){
-		centerPopupWindow($("TreeDialogNewInfoStore"));
-		document.getElementById("TreeDialogNewInfoStore").style.display = "block";
-		document.getElementById("TreeDialogNewInfoStore").style.top = "30px";
-		document.getElementById("TreeDialogNewInfoStore").style.left = "170px";
+function toggleTreeDialog() {
+	if (!treeVisible){
+		centerPopupWindow($("TreeDialogNewInfoStore"), 400, 300);
+		$("TreeDialogNewInfoStore").style.display = "block";
 		treeVisible = true;
-		if(!bCreated) 
-			{
-			loadFolderTreeInfo();
-			bCreated = true;
-			}
-	}
-	else {
-		document.getElementById("TreeDialogNewInfoStore").style.display = "none";
+		if (!bCreated) {
+		    loadFolderTreeInfo();
+		    bCreated = true;
+	    }
+	} else {
+		$("TreeDialogNewInfoStore").style.display = "none";
 		treeVisible = false;
 	}
+	ox.api.setModal(treeVisible);
 }
 
-function folderAction(data)
-{
-	var setEditedFolder = true;
-	hideTree();
+function folderAction(data) {
+	setEditedFolder = true;
+	toggleTreeDialog();
 	clickedItem = data.id;
 	ox.api.folder.getPathString({
 	    folder: clickedItem,
@@ -391,8 +375,8 @@ aFolderViewSettings["default"] = 4;
 aFolderViewSettingsBM["infostore"] = 8;
 var disableOther=true;
 
-function loadFolderTreeInfo()
-{
+function loadFolderTreeInfo() {
+    addOnClose($("TreeDialogNewInfoStore"), toggleTreeDialog);
 	ox.api.ui.selectFolder({
     	type: "infostore",
     	id: "select-folder-popup-infostore",
@@ -404,7 +388,6 @@ function loadFolderTreeInfo()
 	bCreated = true;
 }
 
-
 function callback_new(arg) {
 	if (arg.error) {
 	    setModalBusy(false);
@@ -669,4 +652,5 @@ ctrl.set("beforeunload", function () {
     }
 });
 
-ctrl.set("confirm", cancelNewInfoItem);
\ No newline at end of file
+ctrl.set("confirm", cancelNewInfoItem);
+ctrl.set("dirty", setBeforeUnload);
\ No newline at end of file
