@@ -166,12 +166,8 @@ function deleteMails(folder, ids) {
     // return if ids is empty or a delete is still in progress
     if (!ids || ids.length == 0) return;
     function cb() {
-        if (corewindow.currentpath.join("/").match(/^mail\//) && corewindow.grid) {
-            var focusPos = corewindow.grid.focus;
-            var obj = corewindow.grid.collection.objects[focusPos];
-            if(corewindow.grid.collection.objects.length) {
-                corewindow.grid.selection.click(obj ? focusPos : 0);  
-            }            
+        if (corewindow.currentpath[0] === "mail") {
+            corewindow.setFocus(corewindow.$("mail." + corewindow.currentpath[1] + ".grid"));
         }
         setTimeout(function() {
             ctrl.close(true);
@@ -480,9 +476,6 @@ function drawMessage(message, folder) {
         dateToShow = message["sent_date"];
     }
 	setDate(dateToShow);
-	// change header description if the folder is sent or draft
-    jQuery(".received").text(isStdFolder("sent") ||  isStdFolder("drafts") ? 
-            _("Sent").toString() : _("Received").toString());
 	setMessageText(message);
 	msgref = message["msgref"];
 	setFlagImage(message["flags"]);
@@ -526,8 +519,18 @@ function setPriority(priority) {
 }
 
 function setSubject(subject) {
-    if (subject)
-        $("mail.detail.pop.detail.header.subject").firstChild.nodeValue = subject.replace(/(.{1,20})/g, "$1\u200B");
+    if (subject) {
+        var empty = subject.split(" "), newSubject = "";
+        for (var is=0; is < empty.length; is++) {
+            if (empty[is].length >= 90) {
+                newSubject += empty[is].replace(new RegExp("(.{1,90})", "g"), "$1\u200B");
+            } else {
+                newSubject += empty[is] + " ";
+            }
+        }
+        subject = newSubject;
+        $("mail.detail.pop.detail.header.subject").firstChild.nodeValue = subject;
+    }
 }
 
 function setDate(date) {
@@ -706,9 +709,13 @@ function setMessageText(message) {
     if (ih && ih.document) {
         ih = ih.document;
         ih.open();
-        ih.writeln('<html><head><title></title>'
+        ih.writeln('<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN"'
+                + '     "http://www.w3.org/TR/html4/strict.dtd">'
+                + '<html><head><title>' + (message.subject || "") + '</title>'
+                + '<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">'
+                + '<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=IE7">'
                 + '<base href="' + "[protocol]://[hostname][path]newInfoItemHidden.html".format()  + '">'
-                + '<link type="text/css" rel="stylesheet" href="' + ox.gui.themePath + "css/iframe.css" + '"></link>'
+                + '<link type="text/css" rel="stylesheet" href="' + ox.gui.themePath + "css/iframe.css" + '">'
                 + '</head><body>' + cnn + '</body></html>');
         ih.close();
         setTimeout(function() {
