@@ -104,8 +104,8 @@ var setMailHeaderLabel;
             "to" : addTranslated(_("To")),
             "subject" : addTranslated(_("Subject")),
             "size" : addTranslated(_("Size")),
-            "sent_date" : addTranslated(_("Sent")),
-            "received_date" : addTranslated(_("Received")),
+            "sent_date" : addTranslated(_("Date")),
+            "received_date" : addTranslated(_("Date")),
             "flags_sort" : addTranslated(_("Read/Unread")),
             "color_label": addTranslated(_("Flag"))
         };
@@ -213,22 +213,39 @@ var setMailHeaderLabel;
                 + "&src=1"
                 + "&save=1"
                 + "&session=" + session;
-            // more than one message so we need ZIP
-            if (messages.length !== 1) {
-                action = "zip_messages";
-            }
+            
             // iterate trough selection and build id string
+            var idArray = new Array();
             for (var i=0; i < messages.length; i++) {
                 id += messages[i].id;
+                idArray.push({ id: messages[i].id });
                 // more than one message means comma seperated string
                 if (i+1 < messages.length) {
                     id += ",";
                 }
             }
-            // format url
-            url = url.format({ action: action, id: encodeURIComponent(id) });
-            // set ifram url
-            jQuery("#mail\\." + view.name + "\\.attachment\\.save").attr("src", url);
+            
+            // more than one message so we need ZIP
+            if (messages.length !== 1) {
+                var form;
+                jQuery("body").remove("#form-save")
+                .append(
+            		form = jQuery("<form>").attr({ 
+            			target: "mail." + view.name + ".attachment.save",
+            			method: "post",
+            			id: "form-save",
+            			action: AjaxRoot + "/mail?session=" + session + "&folder=" + activefolder + "&action=zip_messages&save=1"
+            		}).append(
+                		jQuery("<input>").attr({ name: "id", value: id })
+                	)
+                );
+                form.submit();
+            } else {
+            	// format url
+                url = url.format({ action: action, id: encodeURIComponent(id) });
+                // set ifram url
+                jQuery("#mail\\." + view.name + "\\.attachment\\.save").attr("src", url);
+            }
         }
     );
     register("OX_Attachment_Open", function(){ if (activemodule == "mail") openAttachment("OPEN"); });
@@ -284,10 +301,6 @@ var setMailHeaderLabel;
                   _("Mailtext")],
                 { from: !to, to: to, cc: true, subject: true, mailtext: false }
         );
-
-        // change header description if the folder is sent
-        jQuery(".received").text(isStdFolder("sent") ?
-                _("Sent").toString() : _("Received").toString());
     }
 
     /*
@@ -295,6 +308,7 @@ var setMailHeaderLabel;
      * @todo: needs to be optimized
      */
     function updateAfterDeleteSearch() {
+        if (!view.grid.searchActive) return;
         view.grid.searchActive=false;
         if(currentpath[2] == "threaded")
             updateMailStorage("thread", null, "samefolder");
@@ -311,14 +325,15 @@ var setMailHeaderLabel;
 
     function registerList(name, viewObj, param) {
         registerView(name,
-            function() {
+            function () {
                 showNode("mail."+viewObj.name);
             },
-            function(type) {
+            function (type) {
                 view = viewObj;
                 if (!view.grid) {
                     view.grid = initLiveGrid(view);
                 }
+                
                 switchGridHeaders(view.grid);
                 if (viewObj == vsplit) {
                     setVsplitSortEntry();
@@ -335,17 +350,15 @@ var setMailHeaderLabel;
                     switchMailHeaderView(configGetKey("gui.mail.fullmailheader"));
                 }
 
-                if (mail_lastSelectedId && mail_lastSelectedId.directLink &&
-                    mail_lastSelectedId.id)
-                {
+                if (mail_lastSelectedId && mail_lastSelectedId.directLink && mail_lastSelectedId.id) {
                     delete(mail_lastSelectedId.directLink);
                     view.grid.selection.selectIDs([ Key.createfromObject(mail_lastSelectedId) ]);
-                } else {
-                    view.grid.selection.selectIDs(
-                        view.grid.selection.getSelected());
+                    
+                } else if (view.grid.selection.getSelected().length > 0) {
+                    view.grid.selection.selectIDs(view.grid.selection.getSelected());
                 }
                 updateMailStorage(param, undefined, type);
-
+                
                 // trigger selection event
                 triggerEvent("Selected", view.grid.selection.getSelected());
 
@@ -353,11 +366,12 @@ var setMailHeaderLabel;
                     setFocus($("mail." + viewObj.name + ".grid"));
                 }
             },
-            function() {
-                if(detailrequest) {
+            function () {
+                if (detailrequest) {
                     OXCache.unregister(detailrequest.uniqueName);
                     detailrequest=null;
                 }
+                triggerEvent("SubSelected", []);
                 if (viewObj !== list) {
                     clearMailSplitDetail(view.name);
                     unregister("OX_Attachment_SaveInfoStore",mail_saveAttachmentInDocStore);
@@ -366,9 +380,6 @@ var setMailHeaderLabel;
                 unregister("OX_New_Search",searchMail);
                 unregister("OX_Delete_Search",updateAfterDeleteSearch);
                 if (view.grid && view.grid.storage) {
-                    old_focus = grid.focus;
-                    view.grid.disable();
-                } else if(view.grid && view.grid.collection) {
                     old_focus = view.grid.focus;
                     view.grid.disable();
                 }
@@ -377,11 +388,11 @@ var setMailHeaderLabel;
                    $("mail." + view.name + ".attachment.save").src = urlify("newInfoItemHidden.html");
                 }
             },
-            function() {
+            function () {
                 triggerEvent('OX_Delete_Search');
                 hideNode("mail." + viewObj.name);
             },
-            function(type) {
+            function (type) {
                 if(detailrequest) {
                     OXCache.unregister(detailrequest.uniqueName);
                     detailrequest=null;
@@ -399,6 +410,7 @@ var setMailHeaderLabel;
                     view.grid.sort_order = sort_order;
                     view.grid.sort_id = sort_id;
                 }
+                triggerEvent("SubSelected", []);
                 triggerEvent('OX_Delete_Search');
                 setSearch();
                 updateMailStorage(param, undefined, type);
@@ -437,10 +449,8 @@ var setMailHeaderLabel;
         if (sent != Boolean(grid.oldSent)) {
             grid.oldSent = sent;
             if (sent) {
-                columnReceivedSent.text = _("Sent");
                 change("received_date", "sent_date");
             } else {
-                columnReceivedSent.text = _("Received");
                 change("sent_date", "received_date");
             }
         }
@@ -557,10 +567,13 @@ var setMailHeaderLabel;
     };
 
     function clearMailSplitDetail(cview) {
-        $("mail." + view.name + ".detail.header.image_protection").style.display = "none";
-        $("mail." + view.name + ".detail.header.phishing_protection").style.display = "none";
-        $("mail." + view.name + ".detail.row.organization").style.display = "none";
-        jQuery("#mail-" + view.name + "-image").hide();
+        jQuery($("mail." + cview + ".imip")).css({ visibility: "hidden" });
+        jQuery("#mail\\." + cview + "\\.imip\\.toolbar").hide();
+        resizeSplit("mail." + cview + ".imip.toolbar", 0);
+        $("mail." + cview + ".detail.header.image_protection").style.display = "none";
+        $("mail." + cview + ".detail.header.phishing_protection").style.display = "none";
+        $("mail." + cview + ".detail.row.organization").style.display = "none";
+        jQuery("#mail-" + cview + "-image").hide();
 
         if($('mail.' + cview + '.detail.header.from'))
             removeChildNodes($('mail.' + cview + '.detail.header.from'));
@@ -677,7 +690,7 @@ var setMailHeaderLabel;
             grid = initGridHeader();
             $("mail." + view.name + ".grid.header").appendChild(grid.getHeader());
         }
-        grid.sort = updateMailStorage;
+        //grid.sort = updateMailStorage;
         grid.getTable($("mail." + view.name + ".grid"));
         var hovercontent = createHoverContent();
         hovercontent.node.style.display="none";
@@ -913,7 +926,7 @@ var setMailHeaderLabel;
                     }
                     // address string (remove quoting marks
                     var addressString = getAdressString(aAddressToShow, true);
-                    addressString = addressString.replace(/(^"|"$)/g, '');
+                    //addressString = addressString.replace(/(^"|"$)/g, '');
                     // div.style.paddingLeft = content.level + "em";
                     var padding = "";
                     for (var i = 0; i < 20 && i < content["level"]; i++)
@@ -948,7 +961,7 @@ var setMailHeaderLabel;
                 },
                 clear: function(div) { removeChildNodes(div); }
             }, columnReceivedSent = {
-                text: "Received", /*i18n*/
+                text: "Date", /*i18n*/
                 i18n: true,
                 sortable: true,
                 name : ["received_date","flags"],
@@ -1079,7 +1092,7 @@ var setMailHeaderLabel;
             var aAddressToShow = content[to ? "to" : "from"] || [];
             var addressString = getAdressString(aAddressToShow, true);
             // remove quoting marks
-            addressString = addressString.replace(/(^"|"$)/g, '');
+            //addressString = addressString.replace(/(^"|"$)/g, '');
             tds[2].firstChild.data = addressString;
             //deleted
             tds[2].style.textDecoration = content["flags"] & 2 ? "line-through" : "none";
@@ -1253,7 +1266,12 @@ var setMailHeaderLabel;
         function cb_delete() {
             ox.api.folder.refresh({
                 folders: [folder, ox.api.account.get(ox.api.account.derive(folder)).trash_fullname],
-                success: setMailHeaderLabel,
+                success: function() {
+                    setMailHeaderLabel();
+                    if (corewindow.hasFocus) {
+                        setFocus($("mail." + view.name + ".grid"));
+                    }
+                },
                 error: setMailHeaderLabel
             });
         }
@@ -1263,9 +1281,6 @@ var setMailHeaderLabel;
             newConfirm(_("Delete E-Mails"),_('Are you sure you want to delete the selected E-Mails?'),AlertPopup.YESNO,null,null,
             function () {
                 OXMailMapping.deleteObjects(ids,true,cb_delete);
-                if (corewindow.hasFocus) {
-                    setFocus($("mail." + view.name + ".grid"));
-                }
             }, null);
         } else {
             OXMailMapping.deleteObjects(ids,false,cb_delete);
@@ -1406,7 +1421,6 @@ var setMailHeaderLabel;
                 case "from":
                     removeChildNodes(oDivEmails);
                     removeChildNodes(oDivEmailsSmall);
-
                     getAdressStringLinked(oDivEmails, newField, configGetKey("gui.mail.showname"));
 
                     if (oDivEmailsSmall) {
@@ -1458,7 +1472,16 @@ var setMailHeaderLabel;
                         oDivEmails.firstChild.data = " ";
                         oDivEmailsSmall.firstChild.data = " ";
                     } else {
-                        newField = newField.replace(/(.{1,20})/g, "$1\u200B");
+                        var empty = newField.split(" "), newSubject = "", 
+                            split = Math.round(jQuery(document).innerWidth() / 20) || 128;
+                        for (var is=0; is < empty.length; is++) {
+                            if (empty[is].length >= split) {
+                                newSubject += empty[is].replace(new RegExp("(.{1," + split +"})", "g"), "$1\u200B");
+                            } else {
+                                newSubject += empty[is] + " ";
+                            }
+                        }
+                        newField = newSubject;
                     }
                     break;
              }
@@ -1682,9 +1705,13 @@ var setMailHeaderLabel;
                 ih = ih.document;
                 ih.open();
                 // safari needs explicit head/body "around" the content
-                ih.writeln('<html><head><title></title>'
-                        + '<link type="text/css" rel="stylesheet" href="' + ox.gui.themePath + "css/iframe.css" + '"></head>'
-                        + '<body>' + cnn + '</body></html>');
+                ih.writeln('<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN"'
+                        + '     "http://www.w3.org/TR/html4/strict.dtd">'
+                        + '<html><head><title>' + (message.subject || "") + '</title>'
+                        + '<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">'
+                        + '<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=IE7">'
+                        + '<link type="text/css" rel="stylesheet" href="' + ox.gui.themePath + "css/iframe.css" + '">'
+                        + '</head><body>' + cnn + '</body></html>');
                 ih.close();
                 setTimeout(function(){
                     var body = ih.getElementsByTagName("body");
@@ -1886,6 +1913,7 @@ var setMailHeaderLabel;
              + '&session=' + session
              + '&folder=' + encodeURIComponent(context.folder || context.folder_id)
              + '&id=' + encodeURIComponent(context.id);
+        
         if (action == "OPEN") {
             var attachWin = newWindow(
                 n_url + "&attachment=" + selAttach.id + "&save=0&filter=1",
@@ -2026,8 +2054,8 @@ var setMailHeaderLabel;
         var from     = newitem(pgettext("who", "From"),        "from");
         var to       = newitem(_("To"),          "to");
                        newitem(_("Subject"),     "subject");
-        var sent     = newitem(_("Sent"),        "sent_date");
-        var received = newitem(_("Received"),    "received_date");
+        var sent     = newitem(_("Date"),        "sent_date");
+        var received = newitem(_("Date"),    "received_date");
                        newitem(_("Size"),        "size");
                        newitem(_("Read/Unread"), "flags_sort");
                        newitem(_("Flag"),        "color_label");
@@ -2128,10 +2156,14 @@ function getRefToMainForMailPopup() {
  */
 function getAdressString(addresses, personal) {
     var retVal = "";
-    for (a = 0; a < addresses.length; a++) {
+    for (var a = 0; a < addresses.length; a++) {
         var q1 = "", q2 = "";
         if (addresses[a][0] != null) {
-            retVal += addresses[a][0];
+            var pers = addresses[a][0];
+            if ((pers.match(/(")/g) || []).length > 2){
+                pers = pers.replace(/(^"|^'|'$|"$)/g, "");
+            }
+            retVal += pers.replace(/\\"|\\'/g, '"');
             q1 = " <", q2 = ">";
         }
         if ((!personal || addresses[a][0] == null) && addresses[a][1] != null)
