@@ -28,7 +28,7 @@ var oPortalObject = null;
 // -------
 
 var oPortal = (function ($) {
-
+    
     // dom nodes
     var dom = {};
 
@@ -770,24 +770,23 @@ var oPortal = (function ($) {
         var last = join.add();
 
         // get external uwas
-        if (ox.api.config.get("modules.uwaWidgets.enabled") === true) {
-            ox.uwa.list(join.add(function (external) {
-                external = clone(external);
-                if (url.external !== 0) {
-                    // loop over external widgets
-                    var i = 0, $i = external.length, item;
-                    for (; i < $i; i++) {
-                        // get object
-                        item = external[i];
-                        // visible?
-                        if (item.visible) {
-                            item.internal = false;
-                            concat.push(item);
-                        }
-                    }
-                }
-            }));
-        }
+        ox.uwa.list(join.add(function (external) {
+            external = clone(external);
+            if (url.external !== 0) {
+                // loop over external widgets
+                var i = 0, $i = external.length, item;
+                for (; i < $i; i++) {
+                    // get object
+                    item = external[i];
+                    // visible?
+                    if (item.visible) {
+                        item.internal = false;
+                        item["protected"] = ! ox.api.config.get("modules.uwaWidgets.enabled", true);
+                        concat.push(item);
+                    };
+                };
+            };
+        }));
 
         last();
     };
