@@ -229,8 +229,10 @@ split.init = function() {
     var vacationIndex = -1;
     
     split.enableList = function() {
+        split.toolbar.disable();
         ox.JSON.get(AjaxRoot + "/mailfilter?action=list&session=" + session,
             function(reply) {
+                split.toolbar.enable();
                 vacationIndex = -1;
                 for (var i = 0; i < reply.data.length; i++) {
                     if (arrayContains(reply.data[i].flags, "vacation")) {
@@ -515,7 +517,7 @@ split.init = function() {
                         break;
                     default:
                         if (convertLoadTest(d.test)) return cont();
-                        d.test = { id: "anyof", tests: [d.test] };
+                        d.test = { id: "allof", tests: [d.test] };
                 }
                 cont(d);
             });
@@ -523,7 +525,7 @@ split.init = function() {
     
     split.onNew = function() {
         this.addNew({ rulename: _("New rule"), active: true,
-                      test: { id: "anyof", tests: [{ id: "true" }] } });
+                      test: { id: "allof", tests: [{ id: "true" }] } });
     };
 
     menuarrows[node.id] = {};
@@ -658,8 +660,8 @@ split.init = function() {
         _("For an incoming message that matches:")));
     
     var cond_operator = new ox.UI.ComboBox("");
-    cond_operator.setEntries(["anyof", "allof"],
-                             [_("any"), _("all")]);
+    cond_operator.setEntries(["allof", "anyof"],
+                             [_("all"), _("any")]);
     group.addWidget(cond_operator, "id");
 
     group.addWidget(new ox.UI.Text(_("Of the following conditions:")));
@@ -1438,23 +1440,28 @@ function loadVacationPage(cont) {
                 var d = reply.data[0];
                 Self.id = d.id;
                 var start = null, end = null;
-                if (d.test.id == "allof") {
-                    for (var i = 0; i < d.test.tests.length; i++) {
-                        var test = d.test.tests[i];
-                        if (test.id != "currentdate") continue;
-                        switch (test.comparison) {
-                            case "ge":
-                                start = test.datevalue[0];
-                                break;
-                            case "le":
-                                end = test.datevalue[0];
-                                break;
-                            case "is":
-                                start = end = test.datevalue[0];
-                        }
+                function fillStartEnd (test) {
+                    if (test.id != "currentdate") return;
+                    switch (test.comparison) {
+                        case "ge":
+                            start = test.datevalue[0];
+                            break;
+                        case "le":
+                            end = test.datevalue[0];
+                            break;
+                        case "is":
+                            start = end = test.datevalue[0];
                     }
                 }
+                if (d.test.id == "allof") {
+                    for (var i = 0; i < d.test.tests.length; i++) {
+                        fillStartEnd(d.test.tests[i]);
+                    }
+                } else {
+                    fillStartEnd(d.test);
+                }
                 var a = d.actioncmds[0];
+                
                 cont({
                     active: d.active,
                     subject: a.subject,
