@@ -13,40 +13,59 @@
  */
 
 function createContent() {
-    var link = newnode("div", { marginTop: "2em", marginBottom: "2em" }, 0, [
+    var link = newnode("div", { marginTop: "2em", marginBottom: "1.5em" }, 0, [
         newnode("img", { verticalAlign: "middle", paddingRight: "7px" },
             { src: getFullImgSrc("img/infostore/infostore_save.gif") }),
         newnode("a", 0, { href: "#" }, [addTranslated(
-            _("Download updater for the Connector for Microsoft Outlook"))])]);
+            _("Download Updater"))])]);
     addDOMEvent(link, "click", function(e) {
         stopEvent(e);
         $("dlIframe").src =
             AjaxRoot + "/updater/installer/oxupdater-install.exe?session=" + session;
     });
-    return newnode("div", 0, 0, [link,
-        newnode("div", 0, 0, [addTranslated(
-            _("When activating this option an installation wizard will be launched."))]),
-        newnode("div", 0, 0, [addTranslated(
-            _("Follow the instructions and install the updater."))]),
-        newnode("div", 0, 0, [addTranslated(
-            _("The updater will inform you of any updates for the Connector for Microsoft Outlook."))]),
-        newnode("div", 0, 0, [addTranslated(
-            _("You can download the updates from within the updater."))]),
-        newnode("div", { height: "1em" }, 0, []),
-        newnode("div", { fontWeight: "bold" }, 0, [addTranslated(
-            _("Connector for Microsoft Outlook"))]),
-        newnode("div", 0, 0, [addTranslated(
-            _("Enables offline access to e-mail, calendar, tasks, and contacts folders. Any changes that are made using Microsoft Outlook offline will be automatically synchronized the next time you go online:"))]),
-        newnode("div", 0, 0, [addTranslated(
-            _("Client PC operating system: Windows XP, Windows Vista, Windows 7"))]),
-        newnode("div", 0, 0, [
-            addTranslated(_("Supported Outlook versions (Connector 2 for Microsoft Outlook): Latest versions of Microsoft Outlook 2003, Microsoft Outlook 2007, Outlook 2010"))
-        ])
+    
+    var node = newnode("div", 0, 0, [link,
+         newnode("div", 0, 0, [addTranslated(
+             _("When activating this option an installation wizard will be launched."))]),
+         newnode("div", 0, 0, [addTranslated(
+             _("Follow the instructions and install the updater."))]),
+         newnode("div", 0, 0, [addTranslated(
+             _("The updater will inform you of any updates for the Connector for Microsoft Outlook and Notifier."))]),
+         newnode("div", 0, 0, [addTranslated(
+             _("You can download the updates from within the updater."))])
     ]);
+    
+    if (getProduct("com.openexchange.outlook.updater.oxtender2") === true) {
+        jQuery(node).append(
+            newnode("div", { height: "1em" }, 0, []),
+            newnode("div", { fontWeight: "bold" }, 0, [addTranslated(
+                _("Connector for Microsoft Outlook"))]),
+            newnode("div", 0, 0, [addTranslated(
+                _("Enables offline access to e-mail, calendar, tasks, and contacts folders. Any changes that are made using Microsoft Outlook offline will be automatically synchronized the next time you go online:"))]),
+            newnode("div", 0, 0, [addTranslated(
+                _("Client PC operating system: Latest Versions of Windows XP, Windows 7 (each with 32 + 64 bit) (no support of Mac OS X clients with emulators), Windows 8"))]),
+            newnode("div", 0, 0, [
+                addTranslated(_("Supported Outlook versions (Connector 2 for Microsoft Outlook): Latest Versions of Microsoft Outlook 2003, Microsoft Outlook 2007, Outlook 2010 (no support of \"Office 2010 Click-to-Run\", \"Office Home and Business 2010 Testversion\")"))
+            ])
+        )
+    }
+    
+    if (getProduct("com.openexchange.oxnotifier") === true) {
+        jQuery(node).append(
+            newnode("div", { height: "1em" }, 0, []),
+            newnode("div", { fontWeight: "bold" }, 0, [ addTranslated(
+                _("Notifier"))]),
+            newnode("div", 0, 0, [addTranslated(
+                _("Notifier informs the user about the current status of emails and appointments without having to display the user interface."))]),
+            newnode("div", 0, 0, [addTranslated(
+                _("Client PC operation system: Latest Versions of Windows XP, Windows 7 (each with 32 + 64 bit) (no support of Mac OS X clients with emulators)"))])
+        );
+    }
+    return node;
 }
 
 if (configGetKey("modules")["com.openexchange.wizard"] && 
-        configGetKey(["modules", "com.openexchange.oxupdater", "active"]) !== false) {
+        ox.api.config.get(["modules", "com.openexchange.oxupdater", "module"], false) === true) {
     
     // load CSS file
     loadCSSFile(PATH + "/style.css");
@@ -83,16 +102,13 @@ if (configGetKey("modules")["com.openexchange.wizard"] &&
             var title = $("popup.wizzard.header").getElementsByTagName("span")[0];
             removeChildNodes(title);
             if (!this.title) {
-                this.title = addTranslated(format(
-                    //#. %d is the step number.
-                    //#, c-format
-                    _("Step %d. Download Updater"), this.position));
+                this.title = addTranslated(_("Download Updater"));
             }
             title.appendChild(this.title);
             
-            var header = document.getElementById("wizzardHeaderTitle");     
+            var header = document.getElementById("wizzardHeaderTitle");
             removeChildNodes(header);
-            header.appendChild(addTranslated(_("Connector for Microsoft Outlook")));
+            header.appendChild(addTranslated(_("Updater")));
             
             jQuery(this.headerImage)
                 .removeClass("oxupdater-header-wizard_d wizardHeaderImage-disabled wizardHeaderImage-active wizardHeaderImage")
@@ -138,7 +154,7 @@ button.icon = "img/infostore/infostore_save.gif";
 button.disabledIcon = "img/infostore/infostore_save_d.gif";
 button.click = function() { triggerEvent("Feature_MicrosoftOutlook"); };
 menu.add(button);
-if (configGetKey(["modules", "com.openexchange.oxupdater", "active"]) === false) {
+if (getProduct("com.openexchange.outlook.updater.oxtender2") !== true) {
     button.button.options.mousedown = function() {
         corewindow.triggerEvent("Feature_Not_Available", "modules/outlook.updater", window);
     };
@@ -147,13 +163,25 @@ if (configGetKey(["modules", "com.openexchange.oxupdater", "active"]) === false)
 }
 menu.show("portal");
 
-if (configGetKey(["modules", "com.openexchange.oxupdater", "active"]) !== false) {
-    node = new ox.Configuration.LeafNode("configuration/outlook.updater",
-            _("Connector for Microsoft Outlook"));
-    var page = new ox.Configuration.Page(node, _("Connector for Microsoft Outlook"), false);
+if (ox.api.config.get(["modules", "com.openexchange.oxupdater", "module"], false) === true) {
+    node = new ox.Configuration.LeafNode("configuration/outlook.updater", _("Updater"));
+    var page = new ox.Configuration.Page(node, _("Updater"), false);
     page.viewModified = function() { return false; };
     var widget = new ox.UI.Widget();
     widget.content = createContent();
     widget.addContent = function() { this.parent.addRow(this.content); };
     page.addWidget(widget);
 }
+
+function getProduct (key) {
+    var products = ox.api.config.get(["modules", "com.openexchange.oxupdater","products"], []);
+    for (var i=0; i < products.length; i++) {
+        var prod = products[i];
+        for (var a in prod) {
+            if (a === key) {
+                return prod[a];
+            };
+        };
+    }
+    return null;
+};
